@@ -245,7 +245,6 @@ fbdev_modes_equal(struct fb_var_screeninfo *set, struct fb_var_screeninfo *req)
 		set->green.length == req->green.length &&
 		set->blue.length == req->blue.length &&
 		set->xres == req->xres && set->yres == req->yres &&
-		set->pixclock == req->pixclock &&
 		set->right_margin == req->right_margin &&
 		set->hsync_len == req->hsync_len &&
 		set->left_margin == req->left_margin &&
@@ -319,7 +318,13 @@ fbdev_open_pci(struct pci_device * pPci, char **namep)
 		pPci->domain, pPci->bus, pPci->dev, pPci->func, i);
 
 	fd = open(filename, O_RDONLY, 0);
-	if (fd != -1) {
+        if (fd < 0) {
+            sprintf(filename,
+                    "/sys/bus/pci/devices/%04x:%02x:%02x.%d/graphics:fb%d",
+                    pPci->domain, pPci->bus, pPci->dev, pPci->func, i);
+            fd = open(filename, O_RDONLY, 0);
+        }
+	if (fd >= 0) {
 	    close(fd);
 	    sprintf(filename, "/dev/fb%d", i);
 
